===========
Users guide
===========

Networking-Ansible is able to be used in two possible senarios.

The API in Networking-Ansible has been deprecated and will be removed
in the next release. Please use
https://github.com/ansible-network/network-runner instead of the
Networking-Ansible API.

.. toctree::
   :maxdepth: 2

   ironic
   api
